(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     15414,        428]
NotebookOptionsPosition[     13913,        397]
NotebookOutlinePosition[     14322,        413]
CellTagsIndexPosition[     14279,        410]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Created by Marvin Zanke", "Author",
 CellChangeTimes->{{3.814691029353487*^9, 
  3.814691037478608*^9}},ExpressionUUID->"d385ce5d-8155-48ab-9875-\
72783519edf7"],

Cell[CellGroupData[{

Cell["Residue Theorem and Residues in Mathematica", "Title",
 CellChangeTimes->{{3.81468803040672*^9, 3.814688039985806*^9}, {
  3.814690716016181*^9, 
  3.814690717690118*^9}},ExpressionUUID->"1f864e4b-98e5-438e-92aa-\
3960e1efd4e0"],

Cell["\<\
We are going to calculate the integral of equation (3) from H .1) b), third \
exercise sheet, using the Residue Theorem and evaluate the residues here in \
Mathematica. This is always a good cross check for the calculations you did \
by hand (and should definitely be able to do *quickly* by hand).\
\>", "Text",
 CellChangeTimes->{{3.814688041458413*^9, 3.814688130799972*^9}, {
  3.8146881892341013`*^9, 3.814688256333873*^9}, {3.81469006648594*^9, 
  3.814690068440857*^9}},ExpressionUUID->"c4f0313e-58b2-46fb-997e-\
3e8f3fe58500"],

Cell[TextData[{
 "For the integral, we have\n ",
 Cell[BoxData[
  RowBox[{"I", "=", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
    RowBox[{"J", 
     RowBox[{"(", "p", ")"}], 
     RowBox[{"\[DifferentialD]", "p"}]}]}]}]],
  CellChangeTimes->{{3.814690125976634*^9, 3.814690316375923*^9}},
  ExpressionUUID->"415c1d5c-2ca7-4df5-b988-fe62a5adb14c"],
 ",\nwhere \n ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"J", 
    RowBox[{"(", "p", ")"}]}], "=", 
   FractionBox[
    SuperscriptBox["p", "2"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["p", "2"], "-", 
       SuperscriptBox["k", "2"], "-", 
       RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"p", "-", "k"}], ")"}], "2"], "+", 
       SuperscriptBox["\[Mu]", "2"]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"p", "+", "k"}], ")"}], "2"], "+", 
       SuperscriptBox["\[Mu]", "2"]}], ")"}]}]]}]],
  CellChangeTimes->{{3.814690125976634*^9, 3.814690316375923*^9}},
  ExpressionUUID->"570ce918-5001-4755-9bc0-a608500a3958"],
 ".\n Since J(p) is an even function of p, we can write \n",
 Cell[BoxData[
  RowBox[{"I", "=", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
     RowBox[{"J", 
      RowBox[{"(", "p", ")"}], 
      RowBox[{"\[DifferentialD]", "p"}]}]}]}]}]],
  CellChangeTimes->{{3.814690125976634*^9, 3.814690316375923*^9}},
  ExpressionUUID->"6019382d-e7ac-4e96-9821-1ecc9980f838"],
 ";\nmoreover, we add an arc in the upper half of the complex plane (which is \
possible here, as argued several times before) and use the residue theorem: \n\
",
 Cell[BoxData[
  RowBox[{"I", "=", 
   RowBox[{
    FractionBox["1", "2"], "2", "\[Pi]", " ", 
    RowBox[{"\[ImaginaryI]", "[", 
     RowBox[{
      RowBox[{"Res", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"J", 
          RowBox[{"(", "p", ")"}]}], ",", 
         RowBox[{"k", "+", 
          RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}]}], ")"}]}], "+", 
      RowBox[{"Res", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"J", 
          RowBox[{"(", "p", ")"}]}], ",", 
         RowBox[{"k", "+", 
          RowBox[{"\[ImaginaryI]", " ", "\[Mu]"}]}]}], ")"}]}], "+", 
      RowBox[{"Res", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"J", 
          RowBox[{"(", "p", ")"}]}], ",", 
         RowBox[{
          RowBox[{"-", "k"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "\[Mu]"}]}]}], ")"}]}]}], "]"}]}]}]],
  CellChangeTimes->{{3.814690125976634*^9, 3.814690316375923*^9}},
  ExpressionUUID->"d35d8377-08d6-434f-8c68-ec2d7cacc393"]
}], "Text",
 CellChangeTimes->{{3.8146903563858624`*^9, 
  3.8146904893385677`*^9}},ExpressionUUID->"b535cabe-f4f6-4c80-a5f8-\
35a87f5332c8"],

Cell[TextData[{
 "Note that the integrand of equation (3) is in the form  \n",
 Cell[BoxData[
  RowBox[{
   RowBox[{"J", 
    RowBox[{"(", "p", ")"}]}], "=", 
   FractionBox[
    SuperscriptBox["p", "2"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["p", "2"], "-", 
       SuperscriptBox["k", "2"], "-", 
       RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"p", "-", "k"}], ")"}], "2"], "+", 
       SuperscriptBox["\[Mu]", "2"]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"p", "+", "k"}], ")"}], "2"], "+", 
       SuperscriptBox["\[Mu]", "2"]}], ")"}]}]]}]],ExpressionUUID->
  "f1106822-3f12-4fde-b66d-bef5d1589911"],
 ", \nwhere the pole positions are not apparent. Thus, we rewrite it as per  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"J", 
    RowBox[{"(", "p", ")"}]}], "=", 
   FractionBox[
    SuperscriptBox["p", "2"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"p", "+", "k", "+", 
       RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"p", "-", "k", "-", 
       RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"p", "-", "k", "-", 
       RowBox[{"\[ImaginaryI]", " ", "\[Mu]"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"p", "-", "k", "+", 
       RowBox[{"\[ImaginaryI]", " ", "\[Mu]"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"p", "+", "k", "+", 
       RowBox[{"\[ImaginaryI]", " ", "\[Mu]"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"p", "+", "k", "-", 
       RowBox[{"\[ImaginaryI]", " ", "\[Mu]"}]}], ")"}]}]]}]],
  CellChangeTimes->{{3.814688132295528*^9, 3.8146881772801743`*^9}, {
   3.814688320704859*^9, 3.8146883208856497`*^9}, {3.8146884461856833`*^9, 
   3.8146885143304358`*^9}, {3.8146885672695093`*^9, 3.814688592418144*^9}, {
   3.814688639891108*^9, 3.814688640196711*^9}},ExpressionUUID->
  "14233e3c-4c43-4242-b117-0701ecc0284b"],
 "."
}], "Text",
 CellChangeTimes->{{3.81468860267111*^9, 3.8146886750517597`*^9}, {
  3.814690076796586*^9, 3.8146901080217648`*^9}, {3.814690503571342*^9, 
  3.814690520752698*^9}},ExpressionUUID->"d1a53aa7-ba12-45fc-bedd-\
6d3acda1c1c1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Define", " ", "the", " ", "integrand", " ", "as", " ", "a", " ", 
     "function", " ", "of", " ", "p"}], ",", " ", 
    RowBox[{
    "where", " ", "we", " ", "already", " ", "made", " ", "the", " ", "pole", 
     " ", "positions", " ", "apparent", " ", "by", " ", "rewriting", " ", 
     "equation", " ", 
     RowBox[{"(", "3", ")"}], " ", "appropriately", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"see", " ", "text", " ", "above"}], ")"}], "."}]}]}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"J", "[", "p_", "]"}], ":=", 
    FractionBox[
     SuperscriptBox["p", "2"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"p", "+", "k", "+", 
        RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"p", "-", "k", "-", 
        RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"p", "-", "k", "-", 
        RowBox[{"\[ImaginaryI]", " ", "\[Mu]"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"p", "-", "k", "+", 
        RowBox[{"\[ImaginaryI]", " ", "\[Mu]"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"p", "+", "k", "+", 
        RowBox[{"\[ImaginaryI]", " ", "\[Mu]"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"p", "+", "k", "-", 
        RowBox[{"\[ImaginaryI]", " ", "\[Mu]"}]}], ")"}]}]]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.814688132295528*^9, 3.8146881772801743`*^9}, {
  3.814688320704859*^9, 3.8146883208856497`*^9}, {3.8146884461856833`*^9, 
  3.8146885143304358`*^9}, {3.8146885672695093`*^9, 3.814688592418144*^9}, {
  3.814688639891108*^9, 3.81468865855989*^9}, {3.814690564041181*^9, 
  3.814690569719743*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"99e36f80-9f9d-4084-bca2-91f9e5831bf6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Calculate", " ", "the", " ", "three", " ", "residues", " ", "of", " ", 
    "the", " ", "poles", " ", "in", " ", "the", " ", "upper", " ", "half", 
    " ", 
    RowBox[{"plane", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"R1", "=", 
    RowBox[{"Residue", "[", 
     RowBox[{
      RowBox[{"J", "[", "p", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", 
        RowBox[{"k", "+", 
         RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}]}], "}"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"R2", "=", 
    RowBox[{"Residue", "[", 
     RowBox[{
      RowBox[{"J", "[", "p", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", 
        RowBox[{"k", "+", 
         RowBox[{"\[ImaginaryI]", " ", "\[Mu]"}]}]}], "}"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"R3", "=", 
    RowBox[{"Residue", "[", 
     RowBox[{
      RowBox[{"J", "[", "p", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", 
        RowBox[{
         RowBox[{"-", "k"}], "+", 
         RowBox[{"\[ImaginaryI]", " ", "\[Mu]"}]}]}], "}"}]}], 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.814688269993891*^9, 3.814688374244679*^9}, {
  3.814690573804451*^9, 3.814690577059948*^9}, {3.814690618267256*^9, 
  3.814690621398533*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"7f3e0249-3c3f-4e3d-b404-bf53f0f8fb33"],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     RowBox[{"-", "k"}], "-", 
     RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", "-", "\[Mu]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"\[Mu]", "+", "\[Epsilon]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "k"}]}], "-", "\[Mu]", "+", 
       "\[Epsilon]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "k"}]}], "+", "\[Mu]", "+", 
       "\[Epsilon]"}], ")"}]}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.814688316267879*^9, 3.81468834288056*^9}, 
   3.8146883746119623`*^9, 3.814688447935705*^9, 3.8146885181643457`*^9, 
   3.8146905909038897`*^9, 3.814690632694089*^9, 3.814690725255888*^9},
 CellLabel->"Out[2]=",ExpressionUUID->"cf1d9afd-4e70-425c-9902-8849b8d4a8f2"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"k", "+", 
    RowBox[{"\[ImaginaryI]", " ", "\[Mu]"}]}], 
   RowBox[{"8", " ", "k", " ", "\[Mu]", " ", 
    RowBox[{"(", 
     RowBox[{"\[Epsilon]", "-", "\[Mu]"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "k"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "\[Mu]"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}], ")"}]}]], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.814688316267879*^9, 3.81468834288056*^9}, 
   3.8146883746119623`*^9, 3.814688447935705*^9, 3.8146885181643457`*^9, 
   3.8146905909038897`*^9, 3.814690632694089*^9, 3.8146907253326197`*^9},
 CellLabel->"Out[3]=",ExpressionUUID->"8d5bfe2b-85b0-4d76-9696-c9fec94ce2ad"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"k", "-", 
    RowBox[{"\[ImaginaryI]", " ", "\[Mu]"}]}], 
   RowBox[{"8", " ", "k", " ", "\[Mu]", " ", 
    RowBox[{"(", 
     RowBox[{"\[Mu]", "+", "\[Epsilon]"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "k"}], "-", 
      RowBox[{"\[ImaginaryI]", " ", "\[Mu]"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}], ")"}]}]], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.814688316267879*^9, 3.81468834288056*^9}, 
   3.8146883746119623`*^9, 3.814688447935705*^9, 3.8146885181643457`*^9, 
   3.8146905909038897`*^9, 3.814690632694089*^9, 3.814690725394418*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"b25094b1-7733-4c42-a8cd-38fc0c1ca2b0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Combine", " ", "everything", " ", "and", " ", "find", " ", "the", " ", 
     "solution", " ", "of", " ", "the", " ", "integral", " ", "I"}], ",", " ", 
    RowBox[{
     RowBox[{
     "where", " ", "we", " ", "also", " ", "take", " ", "the", " ", "limit", 
      " ", "\[Epsilon]"}], " ", "\[Rule]", " ", 
     RowBox[{"0", " ", 
      RowBox[{"now", "."}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Pi]", " ", "\[ImaginaryI]", 
     RowBox[{"(", 
      RowBox[{"R1", "+", "R2", "+", "R3"}], ")"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{"\[Epsilon]", "\[Rule]", "0"}], "}"}]}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.814690591961388*^9, 3.814690707982293*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"2ad8bf14-1bdd-4069-88e7-a2f9f8e58f7d"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], 
   RowBox[{
    RowBox[{"8", " ", "k", " ", 
     SuperscriptBox["\[Mu]", "2"]}], "+", 
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["\[Mu]", "3"]}]}]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.8146906258498497`*^9, 3.8146906844803743`*^9}, 
   3.814690727867453*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"68c6ba38-0a38-4f03-a2c0-3beafa3a9d20"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{808, 655},
WindowMargins->{{-938, Automatic}, {Automatic, 0}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->FrontEnd`FileName[{"Report"}, "StandardReport.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 167, 3, 40, "Author",ExpressionUUID->"d385ce5d-8155-48ab-9875-72783519edf7"],
Cell[CellGroupData[{
Cell[750, 27, 234, 4, 159, "Title",ExpressionUUID->"1f864e4b-98e5-438e-92aa-3960e1efd4e0"],
Cell[987, 33, 544, 9, 80, "Text",ExpressionUUID->"c4f0313e-58b2-46fb-997e-3e8f3fe58500"],
Cell[1534, 44, 2952, 87, 242, "Text",ExpressionUUID->"b535cabe-f4f6-4c80-a5f8-35a87f5332c8"],
Cell[4489, 133, 2295, 63, 130, "Text",ExpressionUUID->"d1a53aa7-ba12-45fc-bedd-6d3acda1c1c1"],
Cell[6787, 198, 1834, 46, 128, "Input",ExpressionUUID->"99e36f80-9f9d-4084-bca2-91f9e5831bf6"],
Cell[CellGroupData[{
Cell[8646, 248, 1404, 40, 105, "Input",ExpressionUUID->"7f3e0249-3c3f-4e3d-b404-bf53f0f8fb33"],
Cell[10053, 290, 981, 25, 60, "Output",ExpressionUUID->"cf1d9afd-4e70-425c-9902-8849b8d4a8f2"],
Cell[11037, 317, 737, 17, 60, "Output",ExpressionUUID->"8d5bfe2b-85b0-4d76-9696-c9fec94ce2ad"],
Cell[11777, 336, 735, 17, 60, "Output",ExpressionUUID->"b25094b1-7733-4c42-a8cd-38fc0c1ca2b0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12549, 358, 874, 22, 84, "Input",ExpressionUUID->"2ad8bf14-1bdd-4069-88e7-a2f9f8e58f7d"],
Cell[13426, 382, 459, 11, 61, "Output",ExpressionUUID->"68c6ba38-0a38-4f03-a2c0-3beafa3a9d20"]
}, Open  ]]
}, Open  ]]
}
]
*)

